<?xml version="1.0" encoding="UTF-8"?>
<!-- 
  ======================================================================
  このスタイルシートは、「気象庁防災情報XMLフォーマット」に対して活用事例を示すサンプルであり、資料として参照することを目的とする。
  よって、本スタイルシートを直接利用した場合に発生する問題に対して、気象庁は責任を負わない。
  Copyright (c) 気象庁 2010 All rights reserved.

  【本スタイルシートの説明】
　火山の状況に関する解説情報のXML電文を現行テキスト電文に近い形で表示させる例

  【更新履歴】
  2010年04月30日　Ver.1.0 　地震火山部火山課
  ======================================================================
  --> 
<xsl:stylesheet xmlns:jmx="http://xml.kishou.go.jp/jmaxml1/"
 xmlns:jmx_ib="http://xml.kishou.go.jp/jmaxml1/informationBasis1/"
 xmlns:jmx_volc="http://xml.kishou.go.jp/jmaxml1/body/volcanology1/"
 xmlns:jmx_eb="http://xml.kishou.go.jp/jmaxml1/elementBasis1/"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
 <xsl:output method="html" encoding="UTF-8" />

<!-- 文書 -->
<xsl:template match="/">
  <html>
    <xsl:apply-templates select="/jmx:Report"/>
  </html>
</xsl:template>

<!-- 電文 -->
<xsl:template match="/jmx:Report">
  <head>
    <xsl:apply-templates select="jmx:Control"/>
  </head>
  <body>
    <xsl:apply-templates select="jmx_ib:Head"/>
    <xsl:apply-templates select="jmx_volc:Body"/>
  </body>
</xsl:template>

<!-- コントロール部 -->
<xsl:template match="jmx:Control">
  <xsl:copy-of select="jmx:Title"/>
</xsl:template>

<!-- ヘッド部 -->
<xsl:template match="jmx_ib:Head">
  <div align="left">
    <h1><xsl:value-of select="jmx_ib:Title"/>
          <text>　第</text><xsl:value-of select="jmx_ib:Serial"/><text>号</text>
	</h1>
    <p>
      <xsl:value-of select="substring-before(jmx_ib:ReportDateTime,'-')"/>  <xsl:text>年</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,6,2)"/>         <xsl:text>月</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,9,2)"/>         <xsl:text>日</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,12,2)"/>        <xsl:text>時</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,15,2)"/>        <xsl:text>分　</xsl:text>
      <xsl:value-of select="/jmx:Report/jmx:Control/jmx:PublishingOffice"/> <xsl:text>（</xsl:text>
      <xsl:value-of select="jmx_ib:InfoStatus"/>                            <xsl:text>）</xsl:text>
    </p>
  </div>
</xsl:template>

<!-- ボディ部 -->
<xsl:template match="jmx_volc:Body">
  <div align="left"><xsl:apply-templates select="jmx_volc:VolcanoInfoContent/jmx_volc:VolcanoHeadline"/></div>
  <div align="left"><xsl:apply-templates select="jmx_volc:VolcanoInfoContent"/></div>
  <div align="left"><xsl:apply-templates select="jmx_volc:VolcanoInfoContent/jmx_volc:Appendix"/></div>
</xsl:template>

<!-- ボディ部＞見出し -->
<xsl:template match="jmx_volc:VolcanoHeadline">
  <h2><xsl:text>＊＊（見出し）＊＊</xsl:text></h2>
  <p><xsl:value-of select="."/></p>
</xsl:template>

<!-- ボディ部＞本文 -->
<xsl:template match="jmx_volc:VolcanoInfoContent">
  <h2><xsl:text>＊＊（本文）＊＊</xsl:text></h2>
  <div><xsl:apply-templates select="jmx_volc:VolcanoActivity"/></div>
  <div><xsl:apply-templates select="../jmx_volc:VolcanoInfo[@type='噴火警報・予報（対象市町村等）']/jmx_volc:Item/jmx_volc:Areas"/></div>
  <div><xsl:apply-templates select="jmx_volc:VolcanoPrevention"/></div>
</xsl:template>
<!--
<xsl:template match="jmx_volc:VolcanoInfoContent">
  <h2><xsl:text>＊＊（本文）＊＊</xsl:text></h2>
  <div><xsl:apply-templates select="jmx_volc:VolcanoActivity"/></div>
  <div><xsl:apply-templates select="../jmx_volc:VolcanoInfo/jmx_volc:Item/jmx_volc:Areas"/></div>
  <div><xsl:apply-templates select="jmx_volc:VolcanoPrevention"/></div>
</xsl:template>
-->

<!-- ボディ部＞本文＞予警報事項 -->
<xsl:template match="jmx_volc:VolcanoActivity">
  <h3><xsl:text>１．火山活動の状況及び予報警報事項</xsl:text></h3>
  <p><xsl:value-of select="."/></p>
</xsl:template>

<!-- ボディ部＞本文＞対象エリア -->
<xsl:template match="jmx_volc:Areas">
  <h3><xsl:text>２．対象市町村等</xsl:text></h3>
  <xsl:apply-templates select="jmx_volc:Area/jmx_volc:Name"/>
</xsl:template>

<!-- ボディ部＞本文＞対象エリア＞エリア名 -->
<xsl:template match="jmx_volc:Name">
  <p><xsl:value-of select="."/></p>
</xsl:template>

<!-- ボディ部＞本文＞防災事項 -->
<xsl:template match="jmx_volc:VolcanoPrevention">
  <h3><xsl:text>３．防災上の警戒事項等</xsl:text></h3>
  <p><xsl:value-of select="."/></p>
</xsl:template>

<!-- ボディ部＞参考 -->
<xsl:template match="jmx_volc:Appendix">
  <h2><xsl:text>＊＊（参考：噴火警戒レベルの説明）＊＊</xsl:text></h2>
  <p><xsl:value-of select="substring-after(.,'＊＊（参考：噴火警戒レベルの説明）＊＊')"/></p>
</xsl:template>

</xsl:stylesheet>
