<?xml version="1.0" encoding="utf-8"?>

<!--
  ======================================================================
  このスタイルシートは、「気象庁防災情報XMLフォーマット」に対して活用事例を示すサンプルであり、資料として参照することを目的とする。
  よって、本スタイルシートを直接利用した場合に発生する問題に対して、気象庁は責任を負わない。
  Copyright (c) 気象庁 2010 All rights reserved.

  【本スタイルシートの説明】
  警報注意報新ＸＭＬ電文スタイルシート（市町村抜粋）

  【更新履歴】
  2010年4月30日　Ver.1.0 　初期版
  2010年8月 6日　Ver.1.1 　発表官署をEditorialOfficeからPublishingOfficeに変更
  ======================================================================
-->

<xsl:stylesheet 
xmlns:jmx="http://xml.kishou.go.jp/jmaxml1/"
xmlns:jmx_ib="http://xml.kishou.go.jp/jmaxml1/informationBasis1/" 
xmlns:jmx_mete="http://xml.kishou.go.jp/jmaxml1/body/meteorology1/" 
xmlns:jmx_eb="http://xml.kishou.go.jp/jmaxml1/elementBasis1/" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html" indent="yes" />


<!--★★　表示する市町村名を<xsl:variable name="city_name">と</xsl:variable>の間に記入　★★-->
	<xsl:variable name="city_name">福岡市</xsl:variable>


<xsl:template match="/">
	<table width="90%">
		<tr><td>
		<!--ヘッダ部-->
		<xsl:apply-templates select="jmx:Report/jmx_ib:Head" />
		<!--お知らせ-->
			<xsl:apply-templates select="jmx:Report/jmx_mete:Body/jmx_mete:Notice" />
		<!--警報種別（ヘッダ部）-->
			<xsl:apply-templates select="jmx:Report/jmx_ib:Head/jmx_ib:Headline" />
		<!--ヘッダ部と本文の間の罫線-->
			<br/><hr width="70%" size="1" /><br/>
		<!--ボディ部-->
			<xsl:apply-templates select="jmx:Report/jmx_mete:Body" />
		</td></tr>
	</table>
</xsl:template>


<!--ヘッダ部-->
	<xsl:template match="jmx_ib:Head">
		<h1>
		<!--発表日時-->
			<xsl:text>平成</xsl:text>
			<xsl:value-of select="translate(substring(jmx_ib:ReportDateTime,1,4) - 1988,'0123456789', '０１２３４５６７８９')"/>
			<xsl:text>年</xsl:text>
			<xsl:value-of select="translate(substring(jmx_ib:ReportDateTime,6,1),'0123456789', '　１２３４５６７８９')"/>
			<xsl:value-of select="translate(substring(jmx_ib:ReportDateTime,7,1),'0123456789', '０１２３４５６７８９')"/>
			<xsl:text>月</xsl:text>
			<xsl:value-of select="translate(substring(jmx_ib:ReportDateTime,9,1),'0123456789', '　１２３４５６７８９')"/>
			<xsl:value-of select="translate(substring(jmx_ib:ReportDateTime,10,1),'0123456789', '０１２３４５６７８９')"/>
			<xsl:text>日</xsl:text>
			<xsl:value-of select="translate(substring(jmx_ib:ReportDateTime,12,2),'0123456789', '０１２３４５６７８９')"/>
			<xsl:text>時</xsl:text>
			<xsl:value-of select="translate(substring(jmx_ib:ReportDateTime,15,2),'0123456789', '０１２３４５６７８９')"/>
			<xsl:text>分</xsl:text>
			<xsl:text>　</xsl:text>
		<!--発表官署-->
			<xsl:value-of select="/jmx:Report/jmx:Control/jmx:PublishingOffice"/>
		<!--発表状況-->
			<xsl:text>発表</xsl:text>
			<xsl:if test="contains(jmx_ib:InfoType,'訂正')">
				<xsl:text>（訂正）</xsl:text>
			</xsl:if>
		</h1>
	<!--注意警戒文-->
		<p class="mtx"><b>
			<xsl:text>（（</xsl:text>
			<xsl:value-of select="jmx_ib:Headline/jmx_ib:Text"/>
			<xsl:text>））</xsl:text></b>
		</p>
		<br/>
</xsl:template>


<!--お知らせ-->
	<xsl:template match="jmx_mete:Notice">
		<p class="mtx">
			<xsl:text>お知らせ：</xsl:text>
			<xsl:value-of select="." />
		</p>
	</xsl:template>


<!--警報注意報（ヘッダ部・市町村）-->
	<xsl:template match="jmx_ib:Headline">
		<br/><br/>
		<xsl:for-each select="jmx_ib:Information[@type='気象警報・注意報（市町村等）']/jmx_ib:Item">
			<xsl:if test="jmx_ib:Areas/jmx_ib:Area/jmx_ib:Name=$city_name">
			<!--市町村名-->
				<xsl:choose>
				<!--当該市町村の警報注意報種別に変化があった場合-->
					<xsl:when test="../../../../jmx_mete:Body/jmx_mete:Warning/jmx_mete:Item[./jmx_mete:Area/jmx_mete:Name = current()/jmx_ib:Areas/jmx_ib:Area/jmx_ib:Name]/jmx_mete:ChangStatus = '警報注意報種別に変化有'">
						<b><font color="red">
							<xsl:value-of select="jmx_ib:Areas/jmx_ib:Area/jmx_ib:Name" />
						</font></b>
					</xsl:when>
				<!--当該市町村の警報注意報種別に変化がない場合-->
					<xsl:otherwise>
						<b><xsl:value-of select="jmx_ib:Areas/jmx_ib:Area/jmx_ib:Name" /></b>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text>　　</xsl:text>
			<!--警報-->
				<xsl:text>［警報］</xsl:text>
				<xsl:choose>
				<!--発表中の警報がある場合-->
					<xsl:when test="count(jmx_ib:Kind/jmx_ib:Name[contains(.,'警')!=0])>0">
						<xsl:for-each select="jmx_ib:Kind[contains(jmx_ib:Name,'警')!=0]">
							<span style="background-color: pink">
								<xsl:value-of select="substring-before(jmx_ib:Name, '警')" />
							<!-- Conditionがある場合-->
								<xsl:if test="count(jmx_ib:Condition)!= 0">
									<xsl:text>（</xsl:text>
									<xsl:value-of select="jmx_ib:Condition" />
									<xsl:text>）</xsl:text>
								</xsl:if>
							</span>
							<xsl:if test="position() != last()">
								<xsl:text>，　</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
				<!-- 発表中の警報がない場合 -->
					<xsl:otherwise>
						<xsl:text>なし</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text>　　</xsl:text>
			<!-- 注意報 -->
				<xsl:text>［注意報］</xsl:text>
				<xsl:choose>
				<!-- 発表中の注意報がある場合 -->
					<xsl:when test="count(jmx_ib:Kind/jmx_ib:Name[contains(.,'注')!=0])>0">
						<xsl:for-each select="jmx_ib:Kind[contains(jmx_ib:Name,'注')!=0]">
							<span style="background-color: yellow">
								<xsl:value-of select="substring-before(jmx_ib:Name, '注')" />
							</span>
							<xsl:if test="position() != last()">
								<xsl:text>，　</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
				<!-- 発表中の注意報がない場合 -->
					<xsl:otherwise>
						<xsl:text>なし</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<br/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>


<!--ボディ部（市町村等）-->
<xsl:template match="jmx_mete:Body">
	<xsl:for-each select="jmx_mete:Warning[@type='気象警報・注意報（市町村等）']/jmx_mete:Item">
		<xsl:if test="jmx_mete:Area/jmx_mete:Name=$city_name">
		<!--警報注意報種別-->
			<xsl:for-each select="jmx_mete:Kind">
				<xsl:text>　　　</xsl:text>
				<xsl:choose>
				<!--警報-->
					<xsl:when test="contains(jmx_mete:Name,'警')!=0 and contains(jmx_mete:Status,'解除')=0">
						<b><font color="red">
							<xsl:value-of select="jmx_mete:Name" />
							<xsl:if test="count(jmx_mete:Condition)>0">
								<xsl:text>（</xsl:text>
								<xsl:value-of select="jmx_mete:Condition" />
								<xsl:text>）</xsl:text>
							</xsl:if>
						</font>
						<xsl:text>　　</xsl:text>
						<xsl:text>［</xsl:text>
						<xsl:value-of select="jmx_mete:Status"/>
						<xsl:text>］</xsl:text></b>
					</xsl:when>
				<!--注意報-->
					<xsl:when test="contains(jmx_mete:Name,'注')!=0 and contains(jmx_mete:Status,'解除')=0">
						<b><font color="blue">
							<xsl:value-of select="jmx_mete:Name" />
						</font>
						<xsl:text>　　</xsl:text>
						<xsl:text>［</xsl:text>
						<xsl:value-of select="jmx_mete:Status"/>
						<xsl:text>］</xsl:text></b>
					</xsl:when>
				<!--解除-->
					<xsl:when test="contains(jmx_mete:Status,'解除')!=0">
						<b><xsl:value-of select="jmx_mete:Name" />
						<xsl:text>　　</xsl:text>
						<xsl:text>［</xsl:text>
						<xsl:value-of select="jmx_mete:Status"/>
						<xsl:text>］</xsl:text></b>
					</xsl:when>
				<!-- 発表中の警報注意報がない場合 -->
					<xsl:otherwise>
						<xsl:value-of select="jmx_mete:Status"/>
					</xsl:otherwise>
				</xsl:choose>
				<br/>
			<!--特記事項-->
				<xsl:apply-templates select="jmx_mete:Attention" mode="Attention_temp"/>
			<!--警報予告-->
				<xsl:apply-templates select="jmx_mete:WarningNotice" mode="WarningNotice_temp" />
			<!--量的予想事項-->
				<xsl:apply-templates select="jmx_mete:Property" mode="Property_temp" />
			<!--付加事項-->
				<xsl:apply-templates select="jmx_mete:Addition" mode="Addition_temp" />
				<br/>
			</xsl:for-each>
		</xsl:if>
	</xsl:for-each>
</xsl:template>


<!--特記事項-->
	<xsl:template match="jmx_mete:Attention" mode="Attention_temp">
		<xsl:text>　　　　　</xsl:text>
		<b><xsl:text>特記事項</xsl:text></b>
		<xsl:text>　</xsl:text>
		<xsl:for-each select="./jmx_mete:Note">
			<xsl:value-of select="." />
			<xsl:text>　</xsl:text>
		</xsl:for-each>
		<br/>
	</xsl:template>


<!--警報予告-->
	<xsl:template match="jmx_mete:WarningNotice" mode="WarningNotice_temp">
		<xsl:choose>
			<xsl:when test="count(../jmx_mete:Attention) = 0">
				<xsl:text>　　　　　</xsl:text>
				<b><xsl:text>特記事項</xsl:text></b>
				<xsl:text>　</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>　　　　　　　　　　</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:value-of select="jmx_mete:StartTime/jmx_mete:Date" />
		<xsl:value-of select="jmx_mete:StartTime/jmx_mete:Term" />
		<xsl:text>までに</xsl:text>
		<xsl:value-of select="jmx_mete:Note" />
		<br/>
	</xsl:template>


<!--付加事項-->
	<xsl:template match="jmx_mete:Addition" mode="Addition_temp">
		<xsl:text>　　　　　</xsl:text>
		<b><xsl:text>付加事項</xsl:text></b>
		<xsl:text>　</xsl:text>
		<xsl:for-each select="./jmx_mete:Note">
			<xsl:value-of select="."/>
			<xsl:text>　</xsl:text>
		</xsl:for-each>
		<br/>
	</xsl:template>


<!--プロパティ-->
	<xsl:template match="jmx_mete:Property" mode="Property_temp">
		<xsl:text>　　　　　</xsl:text>
		<b><xsl:value-of select="jmx_mete:Type" /></b>
		<xsl:text>　</xsl:text>
	<!--警戒期間-->
		<xsl:if test="jmx_mete:WarningPeriod">
			<xsl:text>警戒期間　</xsl:text>
			<xsl:if test="jmx_mete:WarningPeriod/jmx_mete:StartTime">
				<xsl:value-of select="jmx_mete:WarningPeriod/jmx_mete:StartTime/jmx_mete:Date" />
				<xsl:value-of select="jmx_mete:WarningPeriod/jmx_mete:StartTime/jmx_mete:Term" />
				<xsl:text>から</xsl:text>
			</xsl:if>
			<xsl:if test="jmx_mete:WarningPeriod/jmx_mete:EndTime">
				<xsl:value-of select="jmx_mete:WarningPeriod/jmx_mete:EndTime/jmx_mete:Date" />
				<xsl:value-of select="jmx_mete:WarningPeriod/jmx_mete:EndTime/jmx_mete:Term" />
				<xsl:choose>
					<xsl:when test="jmx_mete:WarningPeriod/jmx_mete:OverTime">
						<xsl:value-of select="jmx_mete:WarningPeriod/jmx_mete:OverTime" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>まで</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:if test="jmx_mete:WarningPeriod/jmx_mete:ZoneTime">
				<xsl:value-of select="jmx_mete:WarningPeriod/jmx_mete:ZoneTime/jmx_mete:Date" />
				<xsl:value-of select="jmx_mete:WarningPeriod/jmx_mete:ZoneTime/jmx_mete:Term" />
			</xsl:if>
			<br/>
			<xsl:text>　　　　　　　</xsl:text>
		</xsl:if>
	<!--注意期間-->
		<xsl:if test="jmx_mete:AdvisoryPeriod">
			<xsl:text>注意期間　</xsl:text>
			<xsl:if test="jmx_mete:AdvisoryPeriod/jmx_mete:StartTime">
				<xsl:value-of select="jmx_mete:AdvisoryPeriod/jmx_mete:StartTime/jmx_mete:Date" />
				<xsl:value-of select="jmx_mete:AdvisoryPeriod/jmx_mete:StartTime/jmx_mete:Term" />
				<xsl:text>から</xsl:text>
			</xsl:if>
			<xsl:if test="jmx_mete:AdvisoryPeriod/jmx_mete:EndTime">
				<xsl:value-of select="jmx_mete:AdvisoryPeriod/jmx_mete:EndTime/jmx_mete:Date" />
				<xsl:value-of select="jmx_mete:AdvisoryPeriod/jmx_mete:EndTime/jmx_mete:Term" />
				<xsl:choose>
					<xsl:when test="jmx_mete:AdvisoryPeriod/jmx_mete:OverTime">
						<xsl:value-of select="jmx_mete:AdvisoryPeriod/jmx_mete:OverTime" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>まで</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:if test="jmx_mete:AdvisoryPeriod/jmx_mete:ZoneTime">
				<xsl:value-of select="jmx_mete:AdvisoryPeriod/jmx_mete:ZoneTime/jmx_mete:Date" />
				<xsl:value-of select="jmx_mete:AdvisoryPeriod/jmx_mete:ZoneTime/jmx_mete:Term" />
			</xsl:if>
			<br/>
		</xsl:if>
	<!--ピーク時間-->
		<xsl:if test="jmx_mete:PeakTime">
			<xsl:text>　　　　　　　</xsl:text>
			<xsl:choose>
				<xsl:when test="jmx_mete:Type='浸水'">
					<xsl:text>雨のピークは</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>ピークは</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:value-of select="jmx_mete:PeakTime/jmx_mete:Date" />
			<xsl:value-of select="jmx_mete:PeakTime/jmx_mete:Term" />
			<br/>
		</xsl:if>
	<!--雨量-->
		<xsl:if test="jmx_mete:PrecipitationPart">
			<xsl:text>　　　　　　　</xsl:text>
			<xsl:value-of select="jmx_mete:PrecipitationPart/jmx_mete:Base/jmx_eb:Precipitation/@type" />
			<xsl:text>　</xsl:text>
			<xsl:value-of select="jmx_mete:PrecipitationPart/jmx_mete:Base/jmx_eb:Precipitation/@description" />
			<br/>
		</xsl:if>
	<!--風向-->
		<xsl:if test="jmx_mete:WindDirectionPart">
			<xsl:text>　　　　　　　</xsl:text>
			<xsl:value-of select="jmx_mete:WindDirectionPart/jmx_mete:Base/jmx_eb:WindDirection/@description" />
			<xsl:if test="jmx_mete:WindDirectionPart/jmx_mete:Becoming">
				<xsl:text>のち</xsl:text>
				<xsl:value-of select="jmx_mete:WindDirectionPart/jmx_mete:Becoming/jmx_eb:WindDirection/@description" />
			</xsl:if>
			<br/>
		</xsl:if>
	<!--風速-->
		<xsl:if test="jmx_mete:WindSpeedPart">
			<xsl:choose>
				<xsl:when test="jmx_mete:WindSpeedPart/jmx_mete:Base/jmx_mete:Local">
					<xsl:for-each select="jmx_mete:WindSpeedPart/jmx_mete:Base/jmx_mete:Local">
						<xsl:text>　　　　　　　</xsl:text>
						<xsl:value-of select="jmx_mete:AreaName"/>
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:WindSpeed/@type" />
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:WindSpeed/@description" />
						<br/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>　　　　　　　</xsl:text>
					<xsl:value-of select="jmx_mete:WindSpeedPart/jmx_mete:Base/jmx_eb:WindSpeed/@type" />
					<xsl:text>　</xsl:text>
					<xsl:value-of select="jmx_mete:WindSpeedPart/jmx_mete:Base/jmx_eb:WindSpeed/@description" />
					<br/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	<!--湿度-->
		<xsl:if test="jmx_mete:HumidityPart">
			<xsl:text>　　　　　　　</xsl:text>
			<xsl:for-each select="jmx_mete:HumidityPart/jmx_mete:Base/jmx_eb:Humidity">
				<xsl:value-of select="@type" />
				<xsl:text>　</xsl:text>
				<xsl:value-of select="@description" />
				<xsl:text>　</xsl:text>
			</xsl:for-each>
			<br/>
		</xsl:if>
	<!--温度-->
		<xsl:if test="jmx_mete:TemperaturePart">
			<xsl:text>　　　　　　　</xsl:text>
			<xsl:value-of select="jmx_mete:TemperaturePart/jmx_mete:Base/jmx_eb:Temperature/@type" />
			<xsl:text>　</xsl:text>
			<xsl:value-of select="jmx_mete:TemperaturePart/jmx_mete:Base/jmx_eb:Temperature/@description" />
			<br/>
		</xsl:if>
	<!--降雪量-->
		<xsl:if test="jmx_mete:SnowfallDepthPart">
			<xsl:choose>
				<xsl:when test="jmx_mete:SnowfallDepthPart/jmx_mete:Base/jmx_mete:Local">
					<xsl:for-each select="jmx_mete:SnowfallDepthPart/jmx_mete:Base/jmx_mete:Local">
						<xsl:text>　　　　　　　</xsl:text>
						<xsl:value-of select="jmx_mete:AreaName"/>
						<xsl:for-each select="jmx_eb:SnowfallDepth">
							<xsl:text>　</xsl:text>
							<xsl:value-of select="@type" />
							<xsl:text>　</xsl:text>
							<xsl:value-of select="@description" />
						</xsl:for-each>
						<br/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>　　　　　　</xsl:text>
					<xsl:for-each select="jmx_mete:SnowfallDepthPart/jmx_mete:Base/jmx_eb:SnowfallDepth">
						<xsl:text>　</xsl:text>
						<xsl:value-of select="@type" />
						<xsl:text>　</xsl:text>
						<xsl:value-of select="@description" />
					</xsl:for-each>
					<br/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	<!--視程-->
		<xsl:if test="jmx_mete:VisibilityPart">
			<xsl:choose>
				<xsl:when test="jmx_mete:VisibilityPart/jmx_mete:Base/jmx_mete:Local">
					<xsl:for-each select="jmx_mete:VisibilityPart/jmx_mete:Base/jmx_mete:Local">
						<xsl:text>　　　　　　　</xsl:text>
						<xsl:value-of select="jmx_mete:AreaName"/>
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:Visibility/@type" />
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:Visibility/@description" />
						<br/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>　　　　　　　</xsl:text>
					<xsl:value-of select="jmx_mete:VisibilityPart/jmx_mete:Base/jmx_eb:Visibility/@type" />
					<xsl:text>　</xsl:text>
					<xsl:value-of select="jmx_mete:VisibilityPart/jmx_mete:Base/jmx_eb:Visibility/@description" />
					<br/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	<!--波高-->
		<xsl:if test="jmx_mete:WaveHeightPart">
			<xsl:choose>
				<xsl:when test="jmx_mete:WaveHeightPart/jmx_mete:Base/jmx_mete:Local">
					<xsl:for-each select="jmx_mete:WaveHeightPart/jmx_mete:Base/jmx_mete:Local">
						<xsl:text>　　　　　　　</xsl:text>
						<xsl:value-of select="jmx_mete:AreaName"/>
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:WaveHeight/@type" />
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:WaveHeight/@description" />
						<br/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>　　　　　　　</xsl:text>
					<xsl:value-of select="jmx_mete:WaveHeightPart/jmx_mete:Base/jmx_eb:WaveHeight/@type" />
					<xsl:text>　</xsl:text>
					<xsl:value-of select="jmx_mete:WaveHeightPart/jmx_mete:Base/jmx_eb:WaveHeight/@description" />
					<br/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	<!--潮位-->
		<xsl:if test="jmx_mete:TidalLevelPart">
			<xsl:choose>
				<xsl:when test="jmx_mete:TidalLevelPart/jmx_mete:Base/jmx_mete:Local">
					<xsl:for-each select="jmx_mete:TidalLevelPart/jmx_mete:Base/jmx_mete:Local">
						<xsl:text>　　　　　　　</xsl:text>
						<xsl:value-of select="jmx_mete:AreaName"/>
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:TidalLevel/@type" />
						<xsl:text>　</xsl:text>
						<xsl:value-of select="jmx_eb:TidalLevel/@description" />
						<br/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>　　　　　　　</xsl:text>
					<xsl:value-of select="jmx_mete:TidalLevelPart/jmx_mete:Base/jmx_eb:TidalLevel/@type" />
					<xsl:text>　</xsl:text>
					<xsl:value-of select="jmx_mete:TidalLevelPart/jmx_mete:Base/jmx_eb:TidalLevel/@description" />
					<br/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
